==> jsolution-ui-lib-0.0.33.tgz: package/src/components/Dropdown/MultipleDropdown/MultipleDropdown.stories.tsx <==
import React from "react";
import { options, OptionTypes } from "../DropdownOptionData";
import { Meta, StoryObj } from "@storybook/react";
import MultipleDropdown, { MultipleDropdownProps } from "./index";
import { useState } from "react";

const meta = {
  title: "component/Dropdown/MultipleDropdown",
  component: MultipleDropdown,
  decorators: [
    (Story) => (
      <div
        style={{
          width: "850px",
          display: "flex",
          justifyContent: "center",
          overflow: "visible",
        }}
      >
        <Story />
      </div>
    ),
  ],
  parameters: {
    layout: "centered",
    docs: {
      story: {
        height: "500px",
      },
    },
  },
  argTypes: {
    disable: { control: "boolean" },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof MultipleDropdown>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  const [selectedValues, setSelectedValues] = useState<OptionTypes[]>([]);

  const handleOnClick = (value: OptionTypes | undefined) => {
    if (value === undefined) setSelectedValues([]);
    else if (
      selectedValues.some((data) => value?.phonePlanId === data.phonePlanId)
    ) {
      setSelectedValues(
        selectedValues.filter((v) => v.phonePlanId !== value?.phonePlanId)
      );
    } else setSelectedValues(selectedValues.concat(value!));
  };

  return (
    // <div style={{ width: "300px" }}>
    <MultipleDropdown
      {...args}
      selectedValues={selectedValues}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={handleOnClick}
    />
    // </div>
  );
};

Default.args = {
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const JSX_Element: Story = (
  args: MultipleDropdownProps<OptionTypes>
) => {
  const [selectedValues, setSelectedValues] = useState<OptionTypes[]>([]);

  const handleOnClick = (value: OptionTypes | undefined) => {
    if (value === undefined) setSelectedValues([]);
    else if (
      selectedValues.some((data) => value?.phonePlanId === data.phonePlanId)
    ) {
      setSelectedValues(
        selectedValues.filter((v) => v.phonePlanId !== value?.phonePlanId)
      );
    } else setSelectedValues(selectedValues.concat(value!));
  };

  return (
    <MultipleDropdown
      {...args}
      selectedValues={selectedValues}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={handleOnClick}
      optionElement={({ option }) => (
        <>
          <p>{option.name}</p>
          <span>{option.price.toLocaleString()}원</span>
        </>
      )}
    />
  );
};

JSX_Element.args = {
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const Empty_Data: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  return <MultipleDropdown {...args} />;
};

Empty_Data.args = {
  options: [],
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

==> jsolution-ui-lib-0.0.43.tgz: package/src/components/Dropdown/MultipleDropdown/MultipleDropdown.stories.tsx <==
import React from "react";
import { options, OptionTypes } from "../DropdownOptionData";
import { Meta, StoryObj } from "@storybook/react";
import MultipleDropdown, { MultipleDropdownProps } from "./index";
import { useState } from "react";

const meta = {
  title: "component/Dropdown/MultipleDropdown",
  component: MultipleDropdown,
  decorators: [
    (Story) => (
      <div
        style={{
          width: "850px",
          display: "flex",
          justifyContent: "center",
          overflow: "visible",
        }}
      >
        <Story />
      </div>
    ),
  ],
  parameters: {
    layout: "centered",
    docs: {
      story: {
        height: "500px",
      },
    },
  },
  argTypes: {
    disable: { control: "boolean" },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof MultipleDropdown>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  const [value, setValue] = useState<OptionTypes[]>([]);

  return (
    <MultipleDropdown
      {...args}
      value={value}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={(option) => setValue(option)}
    />
  );
};

Default.args = {
  value: [],
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const JSX_Element: Story = (
  args: MultipleDropdownProps<OptionTypes>
) => {
  const [value, setValue] = useState<OptionTypes[]>([]);

  return (
    <MultipleDropdown
      {...args}
      value={value}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={(option) => setValue(option)}
      optionElement={({ option }) => (
        <>
          <p>{option.name}</p>
          <span>{option.price.toLocaleString()}원</span>
        </>
      )}
    />
  );
};

JSX_Element.args = {
  value: [],
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const Empty_Data: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  return <MultipleDropdown {...args} />;
};

Empty_Data.args = {
  value: [],
  options: [],
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};
